@@ -1,3 +1,4 @@
+import asyncio
 import sys
 
 from autogit.actions._1_parse_arguments import parse_command_line_arguments
@@ -13,18 +14,22 @@ from autogit.utils.print import print_failure
 from autogit.utils.throttled_tasks_executor import ThrottledTasksExecutor
 
 
-def main(args: list[str] | None = None) -> None:
+async def async_main(args: list[str] | None = None) -> None:
     cli_args = parse_command_line_arguments(args)
     repos = get_repository_states(cli_args)
 
-    with ThrottledTasksExecutor(delay_between_tasks=0.1) as executor:
-        if not clone_repositories(repos, executor):
+    async with ThrottledTasksExecutor(delay_between_tasks=0.1) as executor:
+        if not await clone_repositories(repos, executor):
             print_failure('Failed to clone some of the repositories.')
             sys.exit()
-        create_branch_for_each_repo(repos, executor)
-        run_command_for_each_repo(repos, executor)
-        commit_and_push_changes_for_each_repo(repos, executor)
-        create_pull_request_for_each_repo(repos, executor)
+        await create_branch_for_each_repo(repos, executor)
+        await run_command_for_each_repo(repos, executor)
+        await commit_and_push_changes_for_each_repo(repos, executor)
+        await create_pull_request_for_each_repo(repos, executor)
+
+
+def main(args: list[str] | None = None):
+    asyncio.run(async_main(args))
 
 
 if __name__ == '__main__':
