@@ -9,11 +9,13 @@ ACCESS_TOKEN_VAR_NAMES = {
 
 class CloningStates(Enum):
     NOT_STARTED = 'NOT_STARTED'
+    SOURCE_BRANCH_DOES_NOT_EXIST = 'SOURCE_BRANCH_DOES_NOT_EXIST'
     ACCESS_TOKEN_NOT_PROVIDED = 'ACCESS_TOKEN_NOT_PROVIDED'
     CLONING = 'CLONING'
     CLONED = 'CLONED'
     NOT_FOUND = 'NOT_FOUND'
     SKIPPED = 'SKIPPED'
+    DIRECTORY_NOT_EMPTY = 'DIRECTORY_NOT_EMPTY'
 
 
 class PullRequestStates(Enum):
